pub enum BlockedAction {
SuggestCheckedOutStatus,
SendCustomerMessage,
MutateProviderOrPmsRecord,
MoveRefundDiscountOrPayment,
}Expand description
Actions the agent must never perform without a human/operator system of record.
Variants
SuggestCheckedOutStatus
Blocks agents from suggest checked out status until staff or the system of record performs the action.
SendCustomerMessage
Blocks agents from send customer message until staff or the system of record performs the action.
MutateProviderOrPmsRecord
Blocks agents from mutate provider or pms record until staff or the system of record performs the action.
MoveRefundDiscountOrPayment
Blocks agents from move refund discount or payment until staff or the system of record performs the action.