Packet

Struct Packet 

pub struct Packet { /* private fields */ }
Reviewable packet handed to staff or agents with deterministic gates already applied.

Implementations

Source

impl Packet

pub const fn reservation_id(&self) -> Id

Returns the reservation id source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.

pub const fn provenance(&self) -> &Provenance

Returns the provenance source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.

pub const fn staff_handoff(&self) -> &StaffHandoff

Returns the staff handoff source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.

pub const fn completion_status(&self) -> CompletionStatus

Returns the completion status source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.

pub fn suggested_reservation_status(&self) -> Option<Status>

Returns the suggested reservation status source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.

pub fn required_review_gates(&self) -> &[ReviewGate]

Returns the required review gates source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.

pub fn safe_agent_actions(&self) -> &[SafeAgentAction]

Returns the safe agent actions source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.

pub fn blocked_actions(&self) -> &[BlockedAction]

Returns the blocked actions source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.

pub fn audit_event_drafts(&self) -> &[AuditEventDraft]

Returns the audit event drafts source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.