pub struct Request { /* private fields */ }Expand description
Input rules for building the workflow packet from source-grounded records.
Implementations
Sourceimpl Request
impl Request
Sourcepub fn builder() -> RequestBuilder
pub fn builder() -> RequestBuilder
Create an instance of Request using the builder syntax
Sourceimpl Request
impl Request
Sourcepub const fn reservation_id(&self) -> Id
pub const fn reservation_id(&self) -> Id
Returns the reservation id evidence available to checkout completion review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn source_provenance(&self) -> &Provenance
pub const fn source_provenance(&self) -> &Provenance
Returns the source provenance evidence available to checkout completion review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub fn observed_source_status(&self) -> Status
pub fn observed_source_status(&self) -> Status
Returns the observed source status evidence available to checkout completion review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn staff_handoff(&self) -> &StaffHandoff
pub const fn staff_handoff(&self) -> &StaffHandoff
Returns the staff handoff evidence available to checkout completion review while leaving provider, customer, payment, and schedule systems unchanged.