pub struct Packet { /* private fields */ }Expand description
Reviewable packet handed to staff or agents with deterministic gates already applied.
Implementations
Sourceimpl Packet
impl Packet
Sourcepub const fn reservation_id(&self) -> Id
pub const fn reservation_id(&self) -> Id
Returns the reservation id source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn provenance(&self) -> &Provenance
pub const fn provenance(&self) -> &Provenance
Returns the provenance source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn staff_handoff(&self) -> &StaffHandoff
pub const fn staff_handoff(&self) -> &StaffHandoff
Returns the staff handoff source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn completion_status(&self) -> CompletionStatus
pub const fn completion_status(&self) -> CompletionStatus
Returns the completion status source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn suggested_reservation_status(&self) -> Option<Status>
pub fn suggested_reservation_status(&self) -> Option<Status>
Returns the suggested reservation status source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn required_review_gates(&self) -> &[ReviewGate]
pub fn required_review_gates(&self) -> &[ReviewGate]
Returns the required review gates source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn safe_agent_actions(&self) -> &[SafeAgentAction]
pub fn safe_agent_actions(&self) -> &[SafeAgentAction]
Returns the safe agent actions source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn blocked_actions(&self) -> &[BlockedAction]
pub fn blocked_actions(&self) -> &[BlockedAction]
Returns the blocked actions source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn audit_event_drafts(&self) -> &[AuditEventDraft]
pub fn audit_event_drafts(&self) -> &[AuditEventDraft]
Returns the audit event drafts source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.