Request

Struct Request 

pub struct Request { /* private fields */ }
Input contract for building the workflow packet from source-grounded records.

Implementations

Source

impl Request

pub fn builder() -> RequestBuilder

Create an instance of Request using the builder syntax

Source

impl Request

pub const fn reservation_id(&self) -> Id

Returns the reservation id source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.

pub const fn source_provenance(&self) -> &Provenance

Returns the source provenance source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.

pub fn observed_source_status(&self) -> Status

Returns the observed source status source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.

pub const fn staff_handoff(&self) -> &StaffHandoff

Returns the staff handoff source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.