pub struct Request { /* private fields */ }Expand description
Input contract for building the workflow packet from source-grounded records.
Implementations
Sourceimpl Request
impl Request
Sourcepub fn builder() -> RequestBuilder
pub fn builder() -> RequestBuilder
Create an instance of Request using the builder syntax
Sourceimpl Request
impl Request
Sourcepub const fn reservation_id(&self) -> Id
pub const fn reservation_id(&self) -> Id
Returns the reservation id source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn source_provenance(&self) -> &Provenance
pub const fn source_provenance(&self) -> &Provenance
Returns the source provenance source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn observed_source_status(&self) -> Status
pub fn observed_source_status(&self) -> Status
Returns the observed source status source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn staff_handoff(&self) -> &StaffHandoff
pub const fn staff_handoff(&self) -> &StaffHandoff
Returns the staff handoff source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.