pub struct StaffHandoff { /* private fields */ }Expand description
Staff handoff carried by the checkout completion workflow; it keeps checkout tasks, payment exceptions, and handoff notes explicit for staff review.
Implementations
Sourceimpl StaffHandoff
impl StaffHandoff
Sourcepub fn builder() -> StaffHandoffBuilder
pub fn builder() -> StaffHandoffBuilder
Create an instance of StaffHandoff using the builder syntax
Sourceimpl StaffHandoff
impl StaffHandoff
Sourcepub const fn completed_by(&self) -> &ActorRef
pub const fn completed_by(&self) -> &ActorRef
Returns the completed by source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn completed_at(&self) -> DateTime<Utc>
pub const fn completed_at(&self) -> DateTime<Utc>
Returns the completed at source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn belongings_status(&self) -> BelongingsStatus
pub const fn belongings_status(&self) -> BelongingsStatus
Returns the belongings status source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn care_summary(&self) -> &CareSummary
pub const fn care_summary(&self) -> &CareSummary
Returns the care summary source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn departure_notes_review(&self) -> DepartureNotesReview
pub const fn departure_notes_review(&self) -> DepartureNotesReview
Returns the departure notes review source evidence carried by this checkout completion workflow artifact without changing provider, customer, payment, or schedule state.